# problyStatPy

Python package for computing and visualizing various probability distributions



###  General Module Descriptions:

* Applicable for Gaussian and Binomial distributions
* Read in datasets
* Calculate mean
* Calculate standard deviation
* Compute probability distribution Function
* Plot histogram and bar chart
* Plot probability density function
* Add two distributions
* Return basic statistics of a distribution



### Installation

:link: Instant file download link:
https://pypi.org/project/problystatpy/#files



:sparkles: Command line:
```
$ pip install --user problystatpy
```
​		OR
```
$ python3 -m pip install --user problystatpy
```



### Usage

Recommended for usage accommodation:
```
from problystatpy import *
```

Command line execution:
```
$ python3
>>> from problystatpy import *
>>> gaussian_one = Gaussian()
>>> gaussian_two = Gaussian(25, 2)
>>> gaussian_one.stdev
1
>>> gaussian_one + gaussian_two
mean 25, standard deviation 2.23606797749979
```



### Updates

> 6.22.2020 successfully passed test codes and ready for upload testing
>
> 6.23.2020 problystatpy-0.8.3v release on Test PyPi & pypi.org/project/problystatpy/





### Github

:link: https://github.com/jungsNN/problystatPyP
